@@ -11,9 +11,10 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc., 59
-  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 
   The full GNU General Public License is included in this distribution in the
   file called LICENSE.
@@ -139,15 +140,17 @@ bool GPUSB::updateProperties()
 
     if (isConnected())
     {
-        defineNumber(&GuideNSP);
-        defineNumber(&GuideEWP);
+        defineNumber(&GuideNSNP);
+        defineNumber(&GuideWENP);
     }
     else
     {
-        deleteProperty(GuideNSP.name);
-        deleteProperty(GuideEWP.name);
+        deleteProperty(GuideNSNP.name);
+        deleteProperty(GuideWENP.name);
     }
 
+    return true;
+
 }
 
 void GPUSB::ISGetProperties (const char *dev)
@@ -159,7 +162,7 @@ bool GPUSB::ISNewNumber (const char *dev, const char *name, double values[], cha
 {
     if(strcmp(dev,getDeviceName())==0)
     {
-        if (!strcmp(name,GuideNSP.name) || !strcmp(name,GuideEWP.name))
+        if (!strcmp(name,GuideNSNP.name) || !strcmp(name,GuideWENP.name))
         {
             processGuiderProperties(name, values, names, n);
             return true;
