@@ -25,6 +25,7 @@
 
 #include <memory>
 
+#include <libnova.h>
 
 // We declare an auto pointer to ccdsim.
 std::auto_ptr<CCDSim> ccdsim(0);
@@ -98,9 +99,12 @@ CCDSim::CCDSim()
     HasSt4Port=true;
     HasGuideHead=true;
 
+    polarError=0;
+    polarDrift=0;
 
-    raPEC=9.95;
-    decPEC=68.9;
+    usePE = false;
+    raPE=RA;
+    decPE=Dec;
 
     //  sxvh9
     bias=1500;
@@ -131,9 +135,8 @@ CCDSim::CCDSim()
     TimeFactorSV = new ISwitchVectorProperty;
 
     // Filter stuff
-    MinFilter=1;
-    MaxFilter=5;
-    FilterSlotN[0].max = MaxFilter;
+    FilterSlotN[0].min = 1;
+    FilterSlotN[0].max = 5;
 
 }
 
@@ -150,6 +153,8 @@ bool CCDSim::SetupParms()
     limitingmag=SimulatorSettingsN[7].value;
     saturationmag=SimulatorSettingsN[6].value;
     OAGoffset=SimulatorSettingsN[10].value;    //  An oag is offset this much from center of scope position (arcminutes);
+    polarError=SimulatorSettingsN[11].value;
+    polarDrift=SimulatorSettingsN[12].value;
 
     nbuf = PrimaryCCD.getXRes() * PrimaryCCD.getYRes() * PrimaryCCD.getBPP()/8;
     nbuf += 512;
@@ -190,14 +195,15 @@ bool CCDSim::initProperties()
     IUFillNumber(&SimulatorSettingsN[2],"SIM_XSIZE","CCD X Pixel Size","%4.2f",0,60,0,5.2);
     IUFillNumber(&SimulatorSettingsN[3],"SIM_YSIZE","CCD Y Pixel Size","%4.2f",0,60,0,5.2);
     IUFillNumber(&SimulatorSettingsN[4],"SIM_MAXVAL","CCD Maximum ADU","%4.0f",0,65000,0,65000);
-    IUFillNumber(&SimulatorSettingsN[5],"SIM_BIAS","CCD Bias","%4.0f",0,6000,0,1500);
+    IUFillNumber(&SimulatorSettingsN[5],"SIM_BIAS","CCD Bias","%4.0f",0,6000,0,10);
     IUFillNumber(&SimulatorSettingsN[6],"SIM_SATURATION","Saturation Mag","%4.1f",0,20,0,1.0);
-    IUFillNumber(&SimulatorSettingsN[7],"SIM_LIMITINGMAG","Limiting Mag","%4.1f",0,20,0,20);
-    IUFillNumber(&SimulatorSettingsN[8],"SIM_NOISE","CCD Noise","%4.0f",0,6000,0,50);
+    IUFillNumber(&SimulatorSettingsN[7],"SIM_LIMITINGMAG","Limiting Mag","%4.1f",0,20,0,17.0);
+    IUFillNumber(&SimulatorSettingsN[8],"SIM_NOISE","CCD Noise","%4.0f",0,6000,0,10);
     IUFillNumber(&SimulatorSettingsN[9],"SIM_SKYGLOW","Sky Glow (magnitudes)","%4.1f",0,6000,0,19.5);
     IUFillNumber(&SimulatorSettingsN[10],"SIM_OAGOFFSET","Oag Offset (arcminutes)","%4.1f",0,6000,0,0);
-    IUFillNumberVector(SimulatorSettingsNV,SimulatorSettingsN,11,getDeviceName(),"SIMULATOR_SETTINGS","Simulator Settings","Simulator Config",IP_RW,60,IPS_IDLE);
-
+    IUFillNumber(&SimulatorSettingsN[11],"SIM_POLAR","PAE (arcminutes)","%4.1f",-600,600,0,0); /* PAE = Polar Alignment Error */
+    IUFillNumber(&SimulatorSettingsN[12],"SIM_POLARDRIFT","PAE Drift (minutes)","%4.1f",0,6000,0,0);
+    IUFillNumberVector(SimulatorSettingsNV,SimulatorSettingsN,13,getDeviceName(),"SIMULATOR_SETTINGS","Simulator Settings","Simulator Config",IP_RW,60,IPS_IDLE);
 
     IUFillSwitch(&TimeFactorS[0],"1X","Actual Time",ISS_ON);
     IUFillSwitch(&TimeFactorS[1],"10X","10x",ISS_OFF);
@@ -205,22 +211,29 @@ bool CCDSim::initProperties()
     IUFillSwitchVector(TimeFactorSV,TimeFactorS,3,getDeviceName(),"ON_TIME_FACTOR","Time Factor","Simulator Config",IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
     IUFillNumber(&FWHMN[0],"SIM_FWHM","FWHM (arcseconds)","%4.2f",0,60,0,7.5);
-    IUFillNumberVector(&FWHMNP,FWHMN,1,"Focuser Simulator", "FWHM","FWHM",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
+    IUFillNumberVector(&FWHMNP,FWHMN,1,ActiveDeviceT[1].text, "FWHM","FWHM",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
 
     IUFillNumber(&ScopeParametersN[0],"TELESCOPE_APERTURE","Aperture (mm)","%g",50,4000,0,0.0);
     IUFillNumber(&ScopeParametersN[1],"TELESCOPE_FOCAL_LENGTH","Focal Length (mm)","%g",100,10000,0,0.0 );
     IUFillNumber(&ScopeParametersN[2],"GUIDER_APERTURE","Guider Aperture (mm)","%g",50,4000,0,0.0);
     IUFillNumber(&ScopeParametersN[3],"GUIDER_FOCAL_LENGTH","Guider Focal Length (mm)","%g",100,10000,0,0.0 );
-    IUFillNumberVector(&ScopeParametersNP,ScopeParametersN,4,"Telescope Simulator","TELESCOPE_INFO","Scope Properties",OPTIONS_TAB,IP_RW,60,IPS_OK);
+    IUFillNumberVector(&ScopeParametersNP,ScopeParametersN,4,ActiveDeviceT[0].text,"TELESCOPE_INFO","Scope Properties",OPTIONS_TAB,IP_RW,60,IPS_OK);
 
-    IUFillNumber(&EqPECN[0],"RA_PEC","Ra (hh:mm:ss)","%010.6m",0,24,0,0);
-    IUFillNumber(&EqPECN[1],"DEC_PEC","decPEC (dd:mm:ss)","%010.6m",-90,90,0,0);
-    IUFillNumberVector(&EqPECNP,EqPECN,2,ActiveDeviceT[0].text,"EQUATORIAL_PEC","EQ PEC","Main Control",IP_RW,60,IPS_IDLE);
+    IUFillNumber(&EqPEN[0],"RA_PE","RA (hh:mm:ss)","%010.6m",0,24,0,0);
+    IUFillNumber(&EqPEN[1],"DEC_PE","DEC (dd:mm:ss)","%010.6m",-90,90,0,0);
+    IUFillNumberVector(&EqPENP,EqPEN,2,ActiveDeviceT[0].text,"EQUATORIAL_PE","EQ PE","Main Control",IP_RW,60,IPS_IDLE);
 
-    IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_PEC");
+    IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_PE");
+    IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
+    IDSnoopDevice(ActiveDeviceT[1].text,"FWHM");
 
     initFilterProperties(getDeviceName(), FILTER_TAB);
 
+    FilterSlotN[0].min = 1;
+    FilterSlotN[0].max = 5;
+
+    addDebugControl();
+
     return true;
 }
 
@@ -247,13 +260,18 @@ bool CCDSim::updateProperties()
 
         if(HasGuideHead)
         {
-            SetGuidHeadParams(500,290,16,9.8,12.6);
+            SetGuideHeadParams(500,290,16,9.8,12.6);
             GuideCCD.setFrameBufferSize(GuideCCD.getXRes() * GuideCCD.getYRes() * 2);
         }
 
+        // Define the Filter Slot and name properties
         defineNumber(&FilterSlotNP);
         if (FilterNameT != NULL)
             defineText(FilterNameTP);
+    } else
+    {
+        deleteProperty(FilterSlotNP.name);
+        deleteProperty(FilterNameTP->name);
     }
 
     return true;
@@ -424,7 +442,7 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
     if (targetChip->getXRes() == 500)
     {
         targetFocalLength = guider_focallength;
-        ExposureTime = GuideExposureRequest*4;
+        ExposureTime = GuideExposureRequest;
     }
     else
     {
@@ -432,7 +450,6 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
         ExposureTime = ExposureRequest;
     }
 
-
     if(ShowStarField)
     {
         char gsccmd[250];
@@ -443,10 +460,11 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
         int x,y;
         float PEOffset;
         float PESpot;
+        float decDrift;
         double rad;  //  telescope ra in degrees
         double rar;  //  telescope ra in radians
         double decr; //  telescope dec in radians;
-
+        int nwidth=0, nheight=0;
 
         double timesince;
         time_t now;
@@ -481,9 +499,12 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
         //  for now we cheat
         //  no offset or rotation for and y axis means
         pb=0.0;
-        pc=targetChip->getXRes()/2/targetChip->getBinX();
+        nwidth = targetChip->getXRes() / targetChip->getBinX();
+        pc=nwidth/2;
         pd=0.0;
-        pf=targetChip->getYRes()/2/targetChip->getBinY();
+
+        nheight = targetChip->getYRes() / targetChip->getBinY();
+        pf=nheight/2;
         //  and we do a simple scale for x and y locations
         //  based on the focal length and pixel size
         //  focal length in mm, pixels in microns
@@ -508,15 +529,36 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
         ImageScalex=Scalex;
         ImageScaley=Scaley;
 
+        if (usePE == false)
+        {
+            raPE  = RA;
+            decPE = Dec;
+
+            ln_equ_posn epochPos, J2000Pos;
+            epochPos.ra   = raPE*15.0;
+            epochPos.dec  = decPE;
+
+            // Convert from JNow to J2000
+            ln_get_equ_prec2(&epochPos, ln_get_julian_from_sys(), JD2000, &J2000Pos);
+
+            raPE  = J2000Pos.ra/15.0;
+            decPE = J2000Pos.dec;
+        }
+
         //  calc this now, we will use it a lot later
-        rad=raPEC*15.0;
+        rad=raPE*15.0;
         rar=rad*0.0174532925;
         //  offsetting the dec by the guide head offset
         float cameradec;
-        cameradec=decPEC+OAGoffset/60;
+        cameradec=decPE+OAGoffset/60;
         decr=cameradec*0.0174532925;
 
-        //fprintf(stderr,"decPEC %7.5f  cameradec %7.5f  CenterOffsetDec %4.4f\n",decPEC,cameradec,CenterOffsetDec);
+        decDrift = (polarDrift * polarError * cos(decr)) / 3.81;
+
+        // Add declination drift, if any.
+        decr += decDrift/3600.0 * 0.0174532925;
+
+        //fprintf(stderr,"decPE %7.5f  cameradec %7.5f  CenterOffsetDec %4.4f\n",decPE,cameradec,CenterOffsetDec);
         //  now lets calculate the radius we need to fetch
         float radius;
 
@@ -549,7 +591,7 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
         //  if this is a light frame, we need a star field drawn
         if(targetChip->getFrameType()==CCDChip::LIGHT_FRAME)
         {
-            //sprintf(gsccmd,"gsc -c %8.6f %+8.6f -r 120 -m 0 9.1",rad+PEOffset,decPEC);
+            //sprintf(gsccmd,"gsc -c %8.6f %+8.6f -r 120 -m 0 9.1",rad+PEOffset,decPE);
             sprintf(gsccmd,"gsc -c %8.6f %+8.6f -r %4.1f -m 0 %4.2f -n 3000",rad+PEOffset,cameradec,radius,lookuplimit);
             //fprintf(stderr,"gsccmd %s\n",gsccmd);
             pp=popen(gsccmd,"r");
@@ -613,7 +655,7 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
                         drawn+=rc;
                         if(rc==1)
                         {
-                            //fprintf(stderr,"star %s scope %6.4f %6.4f star %6.4f %6.4f  ccd %6.2f %6.2f\n",id,rad,decPEC,ra,dec,ccdx,ccdy);
+                            //fprintf(stderr,"star %s scope %6.4f %6.4f star %6.4f %6.4f  ccd %6.2f %6.2f\n",id,rad,decPE,ra,dec,ccdx,ccdy);
                             //fprintf(stderr,"star %s ccd %6.2f %6.2f\n",id,ccdx,ccdy);
                         }
                     }
@@ -662,10 +704,11 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
 
             unsigned short *pt;
 
-            int nwidth  = targetChip->getXRes()/targetChip->getBinX();
-            int nheight = targetChip->getYRes()/targetChip->getBinY();
             pt=(unsigned short int *)targetChip->getFrameBuffer();
 
+            nheight = targetChip->getSubH() / targetChip->getBinY();
+            nwidth  = targetChip->getSubW() / targetChip->getBinX();
+
             for(int y=0; y< nheight; y++)
             {
                 for(int x=0; x< nwidth; x++)
@@ -675,12 +718,10 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
                     float sx,sy;
                     float vig;
 
-                    sx=targetChip->getXRes()/2/targetChip->getBinX();
-                    sx=sx-x;
-                    sy=targetChip->getYRes()/2/targetChip->getBinY();
-                    sy=sy-y;
+                    sx=nwidth/2-x;
+                    sy=nheight/2-y;
 
-                    vig=targetChip->getXRes()/targetChip->getBinX();
+                    vig=nwidth;
                     vig=vig*ImageScalex;
                     //  need to make this account for actual pixel size
                     dc=sqrt(sx*sx*ImageScalex*ImageScalex+sy*sy*ImageScaley*ImageScaley);
@@ -713,8 +754,15 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
 
 
         //  Now we add some bias and read noise
-        for(x=0; x<targetChip->getXRes(); x++) {
-            for(y=0; y<targetChip->getYRes(); y++) {
+        int subX = targetChip->getSubX() / targetChip->getBinX();
+        int subY = targetChip->getSubY() / targetChip->getBinX();
+        int subW = targetChip->getSubW() / targetChip->getBinX() + subX;
+        int subH = targetChip->getSubH() / targetChip->getBinX() + subY;
+
+        for(x=subX; x<subW; x++)
+        {
+            for(y=subY; y<subH; y++)
+            {
                 int noise;
 
                 noise=random();
@@ -731,7 +779,7 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
         if(testvalue > 255) testvalue=0;
         val=testvalue;
 
-        int nbuf    = targetChip->getXRes()*targetChip->getYRes();
+        int nbuf    = targetChip->getSubW()*targetChip->getSubH();
 
         for(int x=0; x<nbuf; x++)
         {
@@ -754,19 +802,21 @@ int CCDSim::DrawImageStar(CCDChip *targetChip, float mag,float x,float y)
     float flux;
     float ExposureTime;
 
-    if (targetChip->getXRes() == 500)
-        ExposureTime = GuideExposureRequest*4;
-    else
-        ExposureTime = ExposureRequest;
+    int subX = targetChip->getSubX() / targetChip->getBinX();
+    int subY = targetChip->getSubY() / targetChip->getBinX();
+    int subW = targetChip->getSubW() / targetChip->getBinX() + subX;
+    int subH = targetChip->getSubH() / targetChip->getBinX() + subY;
 
-
-    if((x<0)||(x>targetChip->getXRes()/targetChip->getBinX())||(y<0)||(y>targetChip->getYRes()/targetChip->getBinY()))
+    if((x<subX)||(x>subW||(y<subY)||(y>subH)))
     {
         //  this star is not on the ccd frame anyways
         return 0;
     }
 
-
+    if (targetChip->getXRes() == 500)
+        ExposureTime = GuideExposureRequest*4;
+    else
+        ExposureTime = ExposureRequest;
 
     //  calculate flux from our zero point and gain values
     flux=pow(10,((mag-z)*k/-2.5));
@@ -807,15 +857,6 @@ int CCDSim::DrawImageStar(CCDChip *targetChip, float mag,float x,float y)
 
             if(fp < 0) fp=0;
 
-            /*
-            if(dc < boxsize) {
-                dc=boxsize-dc;
-                dc=dc/boxsize;
-                fp=dc*flux;
-            } else {
-                fp=0;
-            }
-            */
             rc=AddToPixel(targetChip, x+sx,y+sy,fp);
             if(rc != 0) drew=1;
         }
@@ -825,18 +866,24 @@ int CCDSim::DrawImageStar(CCDChip *targetChip, float mag,float x,float y)
 
 int CCDSim::AddToPixel(CCDChip *targetChip, int x,int y,int val)
 {
+    int nwidth = targetChip->getSubW() / targetChip->getBinX();
+    int nheight = targetChip->getSubH() / targetChip->getBinY();
+
+    x -= targetChip->getSubX();
+    y -= targetChip->getSubY();
+
     int drew=0;
     if(x >= 0) {
-        if(x < targetChip->getXRes()/targetChip->getBinX()) {
+        if(x < nwidth) {
             if(y >= 0) {
-                if(y < targetChip->getYRes()/targetChip->getBinY()) {
+                if(y < nheight) {
                     unsigned short *pt;
                     int newval;
                     drew++;
 
                     pt=(unsigned short int *)targetChip->getFrameBuffer();
 
-                    pt+=(y*targetChip->getXRes()/targetChip->getBinX());
+                    pt+=(y*nwidth);
                     pt+=x;
                     newval=pt[0];
                     newval+=val;
@@ -857,7 +904,7 @@ bool CCDSim::GuideNorth(float v)
 
     c=v/1000*GuideRate;  //
     c=c/3600;
-    decPEC=decPEC+c;
+    decPE=decPE+c;
 
     return true;
 }
@@ -867,7 +914,7 @@ bool CCDSim::GuideSouth(float v)
 
     c=v/1000*GuideRate;  //
     c=c/3600;
-    decPEC=decPEC-c;
+    decPE=decPE-c;
 
     return true;
 }
@@ -878,8 +925,8 @@ bool CCDSim::GuideEast(float v)
 
     c=v/1000*GuideRate;
     c=c/3600.0/15.0;
-    c=c/(cos(decPEC*0.0174532925));
-    raPEC=raPEC+c;
+    c=c/(cos(decPE*0.0174532925));
+    raPE=raPE+c;
 
     return true;
 }
@@ -889,8 +936,8 @@ bool CCDSim::GuideWest(float v)
 
     c=v/1000*GuideRate;  //
     c=c/3600.0/15.0;
-    c=c/(cos(decPEC*0.0174532925));
-    raPEC=raPEC-c;
+    c=c/(cos(decPE*0.0174532925));
+    raPE=raPE-c;
 
     return true;
 }
@@ -922,7 +969,7 @@ bool CCDSim::ISNewNumber (const char *dev, const char *name, double values[], ch
 
         if (strcmp(name, FilterSlotNP.name)==0)
         {
-            processFilterProperties(name, values, names, n);
+            processFilterSlot(getDeviceName(), values, names);
             return true;
         }
 
@@ -976,6 +1023,17 @@ bool CCDSim::ISNewSwitch (const char *dev, const char *name, ISState *states, ch
     return INDI::CCD::ISNewSwitch(dev,name,states,names,n);
 }
 
+void CCDSim::activeDevicesUpdated()
+{
+    IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_PE");
+    IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
+    IDSnoopDevice(ActiveDeviceT[1].text,"FWHM");
+
+    strncpy(EqPENP.device, ActiveDeviceT[0].text, MAXINDIDEVICE);
+    strncpy(ScopeParametersNP.device, ActiveDeviceT[0].text, MAXINDIDEVICE);
+    strncpy(FWHMNP.device, ActiveDeviceT[1].text, MAXINDIDEVICE);
+}
+
 bool CCDSim::ISSnoopDevice (XMLEle *root)
 {
      if (IUSnoopNumber(root,&FWHMNP)==0)
@@ -999,17 +1057,28 @@ bool CCDSim::ISSnoopDevice (XMLEle *root)
            return true;
      }
 
-     if(IUSnoopNumber(root,&EqPECNP)==0)
+     // We try to snoop EQPEC first, if not found, we snoop regular EQNP
+     if(IUSnoopNumber(root,&EqPENP)==0)
      {
-        float newra,newdec;
-        newra=EqPECN[0].value;
-        newdec=EqPECN[1].value;
-        if((newra != raPEC)||(newdec != decPEC))
+        double newra,newdec;
+        newra=EqPEN[0].value;
+        newdec=EqPEN[1].value;
+        if((newra != raPE)||(newdec != decPE))
         {
+             ln_equ_posn epochPos, J2000Pos;
+             epochPos.ra   = newra*15.0;
+             epochPos.dec  = newdec;
+
+
+             ln_get_equ_prec2(&epochPos, ln_get_julian_from_sys(), JD2000, &J2000Pos);
+
+             raPE  = J2000Pos.ra/15.0;
+             decPE = J2000Pos.dec;
+
+             usePE = true;
+
             if (isDebug())
-                IDLog("raPEC %4.2f  decPEC %4.2f Snooped raPEC %4.2f  decPEC %4.2f\n",raPEC,decPEC,newra,newdec);
-            raPEC=newra;
-            decPEC=newdec;
+                IDLog("raPE %g  decPE %g Snooped raPE %g  decPE %g\n",raPE,decPE,newra,newdec);
 
             return true;
 
@@ -1033,12 +1102,14 @@ bool CCDSim::SelectFilter(int f)
 {
     CurrentFilter = f;
     SelectFilterDone(f);
+    return true;
 }
 
 bool CCDSim::GetFilterNames(const char* groupName)
 {
     char filterName[MAXINDINAME];
     char filterLabel[MAXINDILABEL];
+    int MaxFilter = FilterSlotN[0].max;
 
     const char *filterDesignation[5] = { "Red", "Green", "Blue", "H_Alpha", "Luminosity" };
 
