@@ -207,6 +207,10 @@ bool RoboFocus::updateProperties()
         defineNumber(&SetBacklashNP);
         defineNumber(&FocusRelPosNP);
         defineNumber(&FocusAbsPosNP);
+
+        GetFocusParams();
+
+       IDMessage(getDeviceName(), "RoboFocus paramaters readout complete, focuser ready for use.");
     }
     else
     {
@@ -259,10 +263,6 @@ bool RoboFocus::Connect()
 
     IDMessage(getDeviceName(), "Robofocus is online. Getting focus parameters...");
 
-    GetFocusParams();
-
-    IDMessage(getDeviceName(), "RoboFocus paramaters readout complete, focuser ready for use.");
-
     return true;
 }
 
@@ -1519,3 +1519,10 @@ int RoboFocus::MoveRel(FocusDirection dir, unsigned int ticks)
 
 }
 
+bool RoboFocus::saveConfigItems(FILE *fp)
+{
+    IUSaveConfigText(fp, &PortTP);
+    IUSaveConfigNumber(fp, &SettingsNP);
+    IUSaveConfigNumber(fp, &SetBacklashNP);
+}
+
