@@ -130,7 +130,25 @@ static int telstat(int fd,int sec,int usec);
 
 int CheckConnectTel(void)
 {
-  return TelConnectFlag;
+    int numRead;
+    char returnStr[128];
+
+  //return TelConnectFlag;
+    tcflush(TelPortFD,TCIOFLUSH);
+
+    /* Test connection */
+
+    writen(TelPortFD,"Kx",2);
+    numRead=readn(TelPortFD,returnStr,3,2);
+    returnStr[numRead] = '\0';
+
+    if (numRead == 2)
+    {
+      TelConnectFlag = 1;
+      return (0);
+    }
+    else
+     return -1;
 }
 
 
@@ -354,6 +372,20 @@ double GetDec(void)
 
 /* Read the telescope right ascension and declination and set update status */
 
+int  isScopeSlewing()
+{
+    int numRead;
+    char returnStr[128];
+
+    writen(TelPortFD,"L",1);
+    numRead=readn(TelPortFD,returnStr,2,2);
+    returnStr[numRead] = '\0';
+
+    // 0 Slew complete
+    // 1 Slew in progress
+    return (returnStr[0] == '0' ? 0 : 1);
+}
+
 void GetRAandDec(void)
 {
   char returnStr[12];
@@ -425,15 +457,125 @@ void GetRAandDec(void)
 
 int SyncToCoords(double newRA, double newDec)
 {
-   offsetRA = 0.;
+ /*  offsetRA = 0.;
    offsetDec = 0.;
    GetRAandDec();
    offsetRA = returnRA - newRA;
    offsetDec = returnDec - newDec;
 
-   return (0);
+   return (0);*/
+
+    /* 2013-10-19 JM: Trying to support sync in Nextstar command set v4.10+ */
+    char str[20];
+    int n1,n2;
+
+    //  so, lets format up a sync command
+    n1=newRA*0x1000000/24;
+    n2=newDec*0x1000000/360;
+    n1=n1<<8;
+    n2=n2<<8;
+    sprintf((char *)str,"s%08X,%08X",n1,n2);
+    writen(TelPortFD,str,18);
+
+    /* Look for '#' in response */
+    for (;;)
+    {
+      if ( readn(TelPortFD,str,1,2) )
+      {
+        if (str[0] == '#') break;
+      }
+      else
+      fprintf(stderr,"No acknowledgment from telescope after SyncToCoords.\n");
+      return 4;
+    }
+    return 0;
 }
 
+/* 2013-11-06 JM: support location update in Nextstar command set */
+int updateLocation(double lng, double lat)
+{
+    int lat_d, lat_m, lat_s;
+    int long_d, long_m ,long_s ;
+
+    char str[10];
+    char cmd[8];
+
+    getSexComponents(lat, &lat_d, &lat_m, &lat_s);
+    getSexComponents(lng, &long_d, &long_m, &long_s);
+
+    // Convert from INDI standard to regular east/west -180 to 180
+    if (long_d > 180)
+        long_d -= 360;
+
+    cmd[0] = abs(lat_d);
+    cmd[1] = lat_m;
+    cmd[2] = lat_s;
+    cmd[3] = lat_d > 0 ? 0 : 1;
+    cmd[4] = abs(long_d);
+    cmd[5] = long_m;
+    cmd[6] = long_s;
+    cmd[7] = long_d > 0 ? 0 : 1;
+
+    sprintf((char *)str, "W%c%c%c%c%c%c%c%c", cmd[0], cmd[1], cmd[2], cmd[3], cmd[4], cmd[5], cmd[6], cmd[7]);
+    writen(TelPortFD,str,9);
+
+    /* Look for '#' in response */
+    for (;;)
+    {
+      if ( readn(TelPortFD,str,1,2) )
+      {
+        if (str[0] == '#') break;
+      }
+      else
+      fprintf(stderr,"No acknowledgment from telescope after updateLocation.\n");
+      return 4;
+    }
+    return 0;
+
+
+}
+
+int updateTime(struct ln_date *utc, double utc_offset)
+{
+    char str[10];
+    char cmd[8];
+    struct ln_zonedate local_date;
+
+    // Celestron takes local time
+    ln_date_to_zonedate(utc, &local_date, utc_offset*3600);
+
+    cmd[0] = local_date.hours;
+    cmd[1] = local_date.minutes;
+    cmd[2] = local_date.seconds;
+    cmd[3] = local_date.months;
+    cmd[4] = local_date.days;
+    cmd[5] = local_date.years - 2000;
+
+    if (utc_offset < 0)
+        cmd[6] = 256 - ((unsigned int) fabs(utc_offset));
+    else
+        cmd[6] = ((unsigned int) fabs(utc_offset));
+
+    // Always assume standard time
+    cmd[7] = 0;
+
+    sprintf((char *)str, "H%c%c%c%c%c%c%c%c", cmd[0], cmd[1], cmd[2], cmd[3], cmd[4], cmd[5], cmd[6], cmd[7]);
+    writen(TelPortFD,str,9);
+
+    /* Look for '#' in response */
+    for (;;)
+    {
+      if ( readn(TelPortFD,str,1,2) )
+      {
+        if (str[0] == '#') break;
+      }
+      else
+      fprintf(stderr,"No acknowledgment from telescope after updateTime.\n");
+      return 4;
+    }
+    return 0;
+
+}
 
 /* Slew to new coordinates */
 /* Coordinate sent to NexStar  = true coordinate + offset. */
