@@ -22,11 +22,11 @@
 #ifndef LX200ASTROPHYSICS_H
 #define LX200ASTROPHYSICS_H
 
-#include "lx200generic.h"
+#include "lx200genericlegacy.h"
 /* thisDevice is not defined with the global section property definitions.*/
 /* So I use this macro throught the lx200ap.cpp */
 /* even one can use thisDevice e.g. in function call like IDMessage( thisDevice,...)*/
-/* That may collide with what is defined in lx200generic.cpp */
+/* That may collide with what is defined in LX200GenericLegacy.cpp */
 #define myapdev "LX200 Astro-Physics"
 
 #define DOMECONTROL 0
@@ -40,7 +40,7 @@
 #define MOUNTNOTINITIALIZED 0 
 #define MOUNTINITIALIZED 1 
 
-class LX200AstroPhysics : public LX200Generic
+class LX200AstroPhysics : public LX200GenericLegacy
 {
  public:
   LX200AstroPhysics();
