@@ -32,8 +32,6 @@ std::auto_ptr<ScopeSim> telescope_sim(0);
 #define GUIDE_WEST      0
 #define GUIDE_EAST      1
 
-
-
 void ISPoll(void *p);
 
 void ISInit()
@@ -93,10 +91,12 @@ void ISSnoopDevice (XMLEle *root)
 ScopeSim::ScopeSim()
 {
     //ctor
-    currentRA=15;
-    currentDEC=15;
+    currentRA=0;
+    currentDEC=90;
     Parked=false;
 
+    DBG_SCOPE = INDI::Logger::getInstance().addDebugLevel("Scope Verbose", "SCOPE");
+
     /* initialize random seed: */
       srand ( time(NULL) );
 }
@@ -117,19 +117,19 @@ bool ScopeSim::initProperties()
     INDI::Telescope::initProperties();
 
     /* Simulated periodic error in RA, DEC */
-    IUFillNumber(&EqPECN[RA_AXIS],"RA_PEC","RA (hh:mm:ss)","%010.6m",0,24,0,15.);
-    IUFillNumber(&EqPECN[DEC_AXIS],"DEC_PEC","DEC (dd:mm:ss)","%010.6m",-90,90,0,15.);
-    IUFillNumberVector(&EqPECNV,EqPECN,2,getDeviceName(),"EQUATORIAL_PEC","Periodic Error",MOTION_TAB,IP_RO,60,IPS_IDLE);
+    IUFillNumber(&EqPEN[RA_AXIS],"RA_PE","RA (hh:mm:ss)","%010.6m",0,24,0,15.);
+    IUFillNumber(&EqPEN[DEC_AXIS],"DEC_PE","DEC (dd:mm:ss)","%010.6m",-90,90,0,15.);
+    IUFillNumberVector(&EqPENV,EqPEN,2,getDeviceName(),"EQUATORIAL_PE","Periodic Error",MOTION_TAB,IP_RO,60,IPS_IDLE);
 
     /* Enable client to manually add periodic error northward or southward for simulation purposes */
-    IUFillSwitch(&PECErrNSS[MOTION_NORTH], "PEC_N", "North", ISS_OFF);
-    IUFillSwitch(&PECErrNSS[MOTION_SOUTH], "PEC_S", "South", ISS_OFF);
-    IUFillSwitchVector(&PECErrNSSP, PECErrNSS, 2, getDeviceName(),"PEC_NS", "PE N/S", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
+    IUFillSwitch(&PEErrNSS[MOTION_NORTH], "PE_N", "North", ISS_OFF);
+    IUFillSwitch(&PEErrNSS[MOTION_SOUTH], "PE_S", "South", ISS_OFF);
+    IUFillSwitchVector(&PEErrNSSP, PEErrNSS, 2, getDeviceName(),"PE_NS", "PE N/S", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
 
     /* Enable client to manually add periodic error westward or easthward for simulation purposes */
-    IUFillSwitch(&PECErrWES[MOTION_WEST], "PEC_W", "West", ISS_OFF);
-    IUFillSwitch(&PECErrWES[MOTION_EAST], "PEC_E", "East", ISS_OFF);
-    IUFillSwitchVector(&PECErrWESP, PECErrWES, 2, getDeviceName(),"PEC_WE", "PE W/E", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
+    IUFillSwitch(&PEErrWES[MOTION_WEST], "PE_W", "West", ISS_OFF);
+    IUFillSwitch(&PEErrWES[MOTION_EAST], "PE_E", "East", ISS_OFF);
+    IUFillSwitchVector(&PEErrWESP, PEErrWES, 2, getDeviceName(),"PE_WE", "PE W/E", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
 
     /* How fast do we guide compared to sidereal rate */
     IUFillNumber(&GuideRateN[RA_AXIS], "GUIDE_RATE_WE", "W/E Rate", "%g", 0, 1, 0.1, 0.3);
@@ -159,12 +159,12 @@ void ScopeSim::ISGetProperties (const char *dev)
 
     if(isConnected())
     {
-        defineNumber(&GuideNSP);
-        defineNumber(&GuideEWP);
+        defineNumber(&GuideNSNP);
+        defineNumber(&GuideWENP);
         defineNumber(&GuideRateNP);
-        defineNumber(&EqPECNV);
-        defineSwitch(&PECErrNSSP);
-        defineSwitch(&PECErrWESP);
+        defineNumber(&EqPENV);
+        defineSwitch(&PEErrNSSP);
+        defineSwitch(&PEErrWESP);
     }
 
     return;
@@ -176,21 +176,21 @@ bool ScopeSim::updateProperties()
 
     if (isConnected())
     {
-        defineNumber(&GuideNSP);
-        defineNumber(&GuideEWP);
+        defineNumber(&GuideNSNP);
+        defineNumber(&GuideWENP);
         defineNumber(&GuideRateNP);
-        defineNumber(&EqPECNV);
-        defineSwitch(&PECErrNSSP);
-        defineSwitch(&PECErrWESP);
+        defineNumber(&EqPENV);
+        defineSwitch(&PEErrNSSP);
+        defineSwitch(&PEErrWESP);
 
     }
     else
     {
-        deleteProperty(GuideNSP.name);
-        deleteProperty(GuideEWP.name);
-        deleteProperty(EqPECNV.name);
-        deleteProperty(PECErrNSSP.name);
-        deleteProperty(PECErrWESP.name);
+        deleteProperty(GuideNSNP.name);
+        deleteProperty(GuideWENP.name);
+        deleteProperty(EqPENV.name);
+        deleteProperty(PEErrNSSP.name);
+        deleteProperty(PEErrWESP.name);
         deleteProperty(GuideRateNP.name);
     }
 
@@ -213,11 +213,13 @@ bool ScopeSim::Connect()
 
 bool ScopeSim::Connect(char *port)
 {
+   DEBUG(INDI::Logger::DBG_SESSION, "Telescope simulator is online.");
    return true;
 }
 
 bool ScopeSim::Disconnect()
 {
+    DEBUG(INDI::Logger::DBG_SESSION, "Telescope simulator is offline.");
     return true;
 }
 
@@ -228,7 +230,7 @@ bool ScopeSim::ReadScopeStatus()
     double dt=0, da_ra=0, da_dec=0, dx=0, dy=0, ra_guide_dt=0, dec_guide_dt=0;
     static double last_dx=0, last_dy=0;
     int nlocked, ns_guide_dir=-1, we_guide_dir=-1;
-    char RA_DISP[64], DEC_DISP[64], RA_GUIDE[64], DEC_GUIDE[64], RA_PEC[64], DEC_PEC[64], RA_TARGET[64], DEC_TARGET[64];
+    char RA_DISP[64], DEC_DISP[64], RA_GUIDE[64], DEC_GUIDE[64], RA_PE[64], DEC_PE[64], RA_TARGET[64], DEC_TARGET[64];
 
 
     /* update elapsed time since last poll, don't presume exactly POLLMS */
@@ -286,7 +288,7 @@ bool ScopeSim::ReadScopeStatus()
     switch (TrackState)
     {
     /*case SCOPE_IDLE:
-        EqNV.s = IPS_IDLE;
+        EqNP.s = IPS_IDLE;
         break;*/
     case SCOPE_SLEWING:
     case SCOPE_PARKING:
@@ -317,29 +319,29 @@ bool ScopeSim::ReadScopeStatus()
         else
           currentDEC -= da_dec;
 
-        EqNV.s = IPS_BUSY;
+        EqNP.s = IPS_BUSY;
 
         if (nlocked == 2)
         {
             if (TrackState == SCOPE_SLEWING)
             {
 
-                // Initially no PEC in both axis.
-                EqPECN[0].value = currentRA;
-                EqPECN[1].value = currentDEC;
+                // Initially no PE in both axis.
+                EqPEN[0].value = currentRA;
+                EqPEN[1].value = currentDEC;
 
-                IDSetNumber(&EqPECNV, NULL);
+                IDSetNumber(&EqPENV, NULL);
 
                 TrackState = SCOPE_TRACKING;
 
-                EqNV.s = IPS_OK;
-                IDMessage(getDeviceName(), "Telescope slew is complete. Tracking...");
+                EqNP.s = IPS_OK;
+                DEBUG(INDI::Logger::DBG_SESSION,"Telescope slew is complete. Tracking...");
             }
             else
             {
                 TrackState = SCOPE_PARKED;
-                EqNV.s = IPS_IDLE;
-                IDMessage(getDeviceName(), "Telescope parked successfully.");
+                EqNP.s = IPS_IDLE;
+                DEBUG(INDI::Logger::DBG_SESSION,"Telescope parked successfully.");
             }
         }
 
@@ -352,14 +354,12 @@ bool ScopeSim::ReadScopeStatus()
         dt *= 1000;
         if (guiderNSTarget[GUIDE_NORTH] > 0)
         {
-            if (isDebug())
-                IDLog("  ****** Commanded to GUIDE NORTH for %g ms *****\n", guiderNSTarget[GUIDE_NORTH]);
+            DEBUGF(INDI::Logger::DBG_DEBUG, "Commanded to GUIDE NORTH for %g ms", guiderNSTarget[GUIDE_NORTH]);
             ns_guide_dir = GUIDE_NORTH;
         }
         else if (guiderNSTarget[GUIDE_SOUTH] > 0)
         {
-            if (isDebug())
-                IDLog("  ****** Commanded to GUIDE SOUTH for %g ms *****\n", guiderNSTarget[GUIDE_SOUTH]);
+            DEBUGF(INDI::Logger::DBG_DEBUG, "Commanded to GUIDE SOUTH for %g ms", guiderNSTarget[GUIDE_SOUTH]);
             ns_guide_dir = GUIDE_SOUTH;
         }
 
@@ -367,14 +367,12 @@ bool ScopeSim::ReadScopeStatus()
         if (guiderEWTarget[GUIDE_WEST] > 0)
         {
             we_guide_dir = GUIDE_WEST;
-            if (isDebug())
-            IDLog("  ****** Commanded to GUIDE WEST for %g ms ****** \n", guiderEWTarget[GUIDE_WEST]);
+            DEBUGF(INDI::Logger::DBG_DEBUG, "Commanded to GUIDE WEST for %g ms", guiderEWTarget[GUIDE_WEST]);
         }
         else if (guiderEWTarget[GUIDE_EAST] > 0)
         {
             we_guide_dir = GUIDE_EAST;
-            if (isDebug())
-               IDLog(" ****** Commanded to GUIDE EAST for %g ms  ****** \n", guiderEWTarget[GUIDE_EAST]);
+            DEBUGF(INDI::Logger::DBG_DEBUG, "Commanded to GUIDE EAST for %g ms", guiderEWTarget[GUIDE_EAST]);
         }
 
         if (ns_guide_dir != -1)
@@ -388,7 +386,7 @@ bool ScopeSim::ReadScopeStatus()
           else              
               guiderNSTarget[ns_guide_dir] = 0;
 
-          EqPECN[DEC_AXIS].value += dec_guide_dt;
+          EqPEN[DEC_AXIS].value += dec_guide_dt;
 
           }
 
@@ -402,7 +400,7 @@ bool ScopeSim::ReadScopeStatus()
           else
                 guiderEWTarget[we_guide_dir] = 0;
 
-          EqPECN[RA_AXIS].value += ra_guide_dt;
+          EqPEN[RA_AXIS].value += ra_guide_dt;
 
           }
 
@@ -413,36 +411,34 @@ bool ScopeSim::ReadScopeStatus()
         // Amount of RA GUIDING correction and direction
         // Amount of DEC GUIDING correction and direction
 
-        dx = EqPECN[RA_AXIS].value - targetRA;
-        dy = EqPECN[DEC_AXIS].value - targetDEC;
+        dx = EqPEN[RA_AXIS].value - targetRA;
+        dy = EqPEN[DEC_AXIS].value - targetDEC;
         fs_sexa(RA_DISP, fabs(dx), 2, 3600 );
         fs_sexa(DEC_DISP, fabs(dy), 2, 3600 );
 
         fs_sexa(RA_GUIDE, fabs(ra_guide_dt), 2, 3600 );
         fs_sexa(DEC_GUIDE, fabs(dec_guide_dt), 2, 3600 );
 
-        fs_sexa(RA_PEC, EqPECN[RA_AXIS].value, 2, 3600);
-        fs_sexa(DEC_PEC, EqPECN[DEC_AXIS].value, 2, 3600);
+        fs_sexa(RA_PE, EqPEN[RA_AXIS].value, 2, 3600);
+        fs_sexa(DEC_PE, EqPEN[DEC_AXIS].value, 2, 3600);
 
         fs_sexa(RA_TARGET, targetRA, 2, 3600);
         fs_sexa(DEC_TARGET, targetDEC, 2, 3600);
 
 
-        if (isDebug() && (dx!=last_dx || dy!=last_dy || ra_guide_dt || dec_guide_dt))
+        if ((dx!=last_dx || dy!=last_dy || ra_guide_dt || dec_guide_dt))
         {
             last_dx=dx;
             last_dy=dy;
-            IDLog("#########################################\n");
-            IDLog("dt is %g\n", dt);
-            IDLog("RA Displacement (%c%s) %s -- %s of target RA %s\n", dx >= 0 ? '+' : '-', RA_DISP, RA_PEC,  (EqPECN[RA_AXIS].value - targetRA) > 0 ? "East" : "West", RA_TARGET);
-            IDLog("DEC Displacement (%c%s) %s -- %s of target RA %s\n", dy >= 0 ? '+' : '-', DEC_DISP, DEC_PEC, (EqPECN[DEC_AXIS].value - targetDEC) > 0 ? "North" : "South", DEC_TARGET);
-            IDLog("RA Guide Correction (%g) %s -- Direction %s\n", ra_guide_dt, RA_GUIDE, ra_guide_dt > 0 ? "East" : "West");
-            IDLog("DEC Guide Correction (%g) %s -- Direction %s\n", dec_guide_dt, DEC_GUIDE, dec_guide_dt > 0 ? "North" : "South");
-            IDLog("#########################################\n");
+            DEBUGF(INDI::Logger::DBG_DEBUG, "dt is %g\n", dt);
+            DEBUGF(INDI::Logger::DBG_DEBUG, "RA Displacement (%c%s) %s -- %s of target RA %s\n", dx >= 0 ? '+' : '-', RA_DISP, RA_PE,  (EqPEN[RA_AXIS].value - targetRA) > 0 ? "East" : "West", RA_TARGET);
+            DEBUGF(INDI::Logger::DBG_DEBUG, "DEC Displacement (%c%s) %s -- %s of target RA %s\n", dy >= 0 ? '+' : '-', DEC_DISP, DEC_PE, (EqPEN[DEC_AXIS].value - targetDEC) > 0 ? "North" : "South", DEC_TARGET);
+            DEBUGF(INDI::Logger::DBG_DEBUG, "RA Guide Correction (%g) %s -- Direction %s\n", ra_guide_dt, RA_GUIDE, ra_guide_dt > 0 ? "East" : "West");
+            DEBUGF(INDI::Logger::DBG_DEBUG, "DEC Guide Correction (%g) %s -- Direction %s\n", dec_guide_dt, DEC_GUIDE, dec_guide_dt > 0 ? "North" : "South");
         }
 
         if (ns_guide_dir != -1 || we_guide_dir != -1)
-            IDSetNumber(&EqPECNV, NULL);
+            IDSetNumber(&EqPENV, NULL);
 
          break;
 
@@ -450,6 +446,13 @@ bool ScopeSim::ReadScopeStatus()
         break;
     }
 
+    char RAStr[64], DecStr[64];
+
+    fs_sexa(RAStr, currentRA, 2, 3600);
+    fs_sexa(DecStr, currentDEC, 2, 3600);
+
+    DEBUGF(DBG_SCOPE, "Current RA: %s Current DEC: %s", RAStr, DecStr);
+
     NewRaDec(currentRA, currentDEC);
     return true;
 }
@@ -467,9 +470,9 @@ bool ScopeSim::Goto(double r,double d)
     Parked=false;
     TrackState = SCOPE_SLEWING;
 
-    EqNV.s    = IPS_BUSY;
+    EqNP.s    = IPS_BUSY;
 
-    IDMessage(getDeviceName(), "Slewing to RA: %s - DEC: %s", RAStr, DecStr);
+    DEBUGF(INDI::Logger::DBG_SESSION,"Slewing to RA: %s - DEC: %s", RAStr, DecStr);
     return true;
 }
 
@@ -478,14 +481,14 @@ bool ScopeSim::Sync(double ra, double dec)
     currentRA  = ra;
     currentDEC = dec;
 
-    EqPECN[RA_AXIS].value = ra;
-    EqPECN[DEC_AXIS].value = dec;
-    IDSetNumber(&EqPECNV, NULL);
+    EqPEN[RA_AXIS].value = ra;
+    EqPEN[DEC_AXIS].value = dec;
+    IDSetNumber(&EqPENV, NULL);
 
-    IDMessage(getDeviceName(), "Sync is successful.");
+    DEBUG(INDI::Logger::DBG_SESSION,"Sync is successful.");
 
     TrackState = SCOPE_IDLE;
-    EqNV.s    = IPS_OK;
+    EqNP.s    = IPS_OK;
 
 
     NewRaDec(currentRA, currentDEC);
@@ -499,7 +502,7 @@ bool ScopeSim::Park()
     targetDEC=90;
     Parked=true;
     TrackState = SCOPE_PARKING;
-    IDMessage(getDeviceName(), "Parking telescope in progress...");
+    DEBUG(INDI::Logger::DBG_SESSION,"Parking telescope in progress...");
     return true;
 }
 
@@ -517,7 +520,7 @@ bool ScopeSim::ISNewNumber (const char *dev, const char *name, double values[],
              return true;
          }
 
-         if (!strcmp(name,GuideNSP.name) || !strcmp(name,GuideEWP.name))
+         if (!strcmp(name,GuideNSNP.name) || !strcmp(name,GuideWENP.name))
          {
              processGuiderProperties(name, values, names, n);
              return true;
@@ -525,8 +528,6 @@ bool ScopeSim::ISNewNumber (const char *dev, const char *name, double values[],
 
     }
 
-
-
     //  if we didn't process it, continue up the chain, let somebody else
     //  give it a shot
     return INDI::Telescope::ISNewNumber(dev,name,values,names,n);
@@ -534,62 +535,52 @@ bool ScopeSim::ISNewNumber (const char *dev, const char *name, double values[],
 
 bool ScopeSim::ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n)
 {
-    //IDLog("Enter IsNewSwitch for %s\n",name);
-    //for(int x=0; x<n; x++) {
-    //    IDLog("Switch %s %d\n",names[x],states[x]);
-    //}
-
     if(strcmp(dev,getDeviceName())==0)
     {
-        if(strcmp(name,"PEC_NS")==0)
+        if(strcmp(name,"PE_NS")==0)
         {
-            IUUpdateSwitch(&PECErrNSSP,states,names,n);
+            IUUpdateSwitch(&PEErrNSSP,states,names,n);
 
-            PECErrNSSP.s = IPS_OK;
+            PEErrNSSP.s = IPS_OK;
 
-            if (PECErrNSS[MOTION_NORTH].s == ISS_ON)
+            if (PEErrNSS[MOTION_NORTH].s == ISS_ON)
             {
-                EqPECN[DEC_AXIS].value += SID_RATE * GuideRateN[DEC_AXIS].value;
-                if (isDebug())
-                    IDLog("$$$$$ Simulating PE in NORTH direction for value of %g $$$$$\n", SID_RATE);
+                EqPEN[DEC_AXIS].value += SID_RATE * GuideRateN[DEC_AXIS].value;
+                DEBUGF(INDI::Logger::DBG_DEBUG, "Simulating PE in NORTH direction for value of %g", SID_RATE);
             }
             else
             {
-                EqPECN[DEC_AXIS].value -= SID_RATE * GuideRateN[DEC_AXIS].value;
-                if (isDebug())
-                    IDLog("$$$$$ Simulating PE in SOUTH direction for value of %g $$$$$\n", SID_RATE);
+                EqPEN[DEC_AXIS].value -= SID_RATE * GuideRateN[DEC_AXIS].value;
+                DEBUGF(INDI::Logger::DBG_DEBUG, "Simulating PE in SOUTH direction for value of %g", SID_RATE);
             }
 
-            IUResetSwitch(&PECErrNSSP);
-            IDSetSwitch(&PECErrNSSP, NULL);
-            IDSetNumber(&EqPECNV, NULL);
+            IUResetSwitch(&PEErrNSSP);
+            IDSetSwitch(&PEErrNSSP, NULL);
+            IDSetNumber(&EqPENV, NULL);
 
             return true;
-
         }
 
-        if(strcmp(name,"PEC_WE")==0)
+        if(strcmp(name,"PE_WE")==0)
         {
-            IUUpdateSwitch(&PECErrWESP,states,names,n);
+            IUUpdateSwitch(&PEErrWESP,states,names,n);
 
-            PECErrWESP.s = IPS_OK;
+            PEErrWESP.s = IPS_OK;
 
-            if (PECErrWES[MOTION_WEST].s == ISS_ON)
+            if (PEErrWES[MOTION_WEST].s == ISS_ON)
             {
-                EqPECN[RA_AXIS].value -= SID_RATE/15. * GuideRateN[RA_AXIS].value;
-                if (isDebug())
-                    IDLog("$$$$$ Simulator PE in WEST direction for value of %g $$$$$$\n", SID_RATE);
+                EqPEN[RA_AXIS].value -= SID_RATE/15. * GuideRateN[RA_AXIS].value;
+                DEBUGF(INDI::Logger::DBG_DEBUG, "Simulator PE in WEST direction for value of %g", SID_RATE);
             }
             else
             {
-                EqPECN[RA_AXIS].value += SID_RATE/15. * GuideRateN[RA_AXIS].value;
-                if (isDebug())
-                    IDLog("$$$$$$ Simulator PE in EAST direction for value of %g $$$$$$\n", SID_RATE);
+                EqPEN[RA_AXIS].value += SID_RATE/15. * GuideRateN[RA_AXIS].value;
+                DEBUGF(INDI::Logger::DBG_DEBUG, "Simulator PE in EAST direction for value of %g", SID_RATE);
             }
 
-            IUResetSwitch(&PECErrWESP);
-            IDSetSwitch(&PECErrWESP, NULL);
-            IDSetNumber(&EqPECNV, NULL);
+            IUResetSwitch(&PEErrWESP);
+            IDSetSwitch(&PEErrWESP, NULL);
+            IDSetNumber(&EqPENV, NULL);
 
             return true;
 
@@ -617,25 +608,26 @@ bool ScopeSim::Abort()
         IDSetSwitch(&MovementWESP, NULL);
     }
 
-    if (ParkSV.s == IPS_BUSY)
+    if (ParkSP.s == IPS_BUSY)
     {
-        ParkSV.s       = IPS_IDLE;
-        IUResetSwitch(&ParkSV);
-        IDSetSwitch(&ParkSV, NULL);
+        ParkSP.s       = IPS_IDLE;
+        IUResetSwitch(&ParkSP);
+        IDSetSwitch(&ParkSP, NULL);
     }
 
-    if (EqNV.s == IPS_BUSY)
+    if (EqNP.s == IPS_BUSY)
     {
-        EqNV.s = IPS_IDLE;
-        IDSetNumber(&EqNV, NULL);
+        EqNP.s = IPS_IDLE;
+        IDSetNumber(&EqNP, NULL);
     }
 
 
     TrackState = SCOPE_IDLE;
 
-    AbortSV.s      = IPS_OK;
-    IUResetSwitch(&AbortSV);
-    IDSetSwitch(&AbortSV, "Telescope aborted.");
+    AbortSP.s      = IPS_OK;
+    IUResetSwitch(&AbortSP);
+    IDSetSwitch(&AbortSP, NULL);
+    DEBUG(INDI::Logger::DBG_SESSION, "Telescope aborted.");
 
     return true;
 }
