@@ -15,9 +15,12 @@
 #include "indibase/defaultdevice.h"
 
 /** \file raindetector.h
-    \brief Construct a rain detector device that the user may operate to raise a rain alert. This rain light property defined by this driver is \e snooped by the Dome driver
-           then takes whatever appropiate action to protect the dome.
-    \author Jasem Mutlaq
+*   \brief Construct a rain detector device that the user may operate to raise a rain alert. This rain light property defined by this driver is \e snooped by the Dome driver
+*         then takes whatever appropiate action to protect the dome.
+*   \author Jasem Mutlaq
+*
+*   \example raindetector.h
+*            The rain detector emits a signal each time it detects raid. This signal is \e snooped by the dome driver.
 */
 
 class RainDetector : public INDI::DefaultDevice
