@@ -355,7 +355,8 @@ void IUFillText(IText *tp, const char *name, const char * label, const char *ini
   tp->aux0 = NULL;
   tp->aux1 = NULL;
 
-  IUSaveText(tp, initialText);
+  if (initialText && strlen(initialText) > 0)
+    IUSaveText(tp, initialText);
 
 }
 
@@ -1722,4 +1723,15 @@ int isPropDefined(const char *property_name)
 
 }
 
+int IUFindIndex (const char *needle, char **hay, unsigned int n)
+{
+    int i=0;
+
+    for (i=0; i < n; i++)
+        if (!strcmp(hay[i], needle))
+            return i;
+
+    return -1;
+}
+
 
