@@ -25,6 +25,8 @@
 #include <netinet/in.h>
 #include <netdb.h>
 #include <fcntl.h>
+#include <locale.h>
+#include <pthread.h>
 
 #include "baseclient.h"
 #include "basedevice.h"
@@ -139,8 +141,8 @@ bool INDI::BaseClient::disconnectServer()
     sConnected = false;
 
     shutdown(sockfd, SHUT_RDWR);
-    write(m_sendFd,"1",1);
 
+    while (write(m_sendFd,"1",1) <= 0)
 
     if (svrwfp != NULL)
         fclose(svrwfp);
@@ -558,6 +560,8 @@ void INDI::BaseClient::sendNewText (const char * deviceName, const char * proper
 
 void INDI::BaseClient::sendNewNumber (INumberVectorProperty *nvp)
 {
+   setlocale(LC_NUMERIC,"C");
+
     nvp->s = IPS_BUSY;
 
     fprintf(svrwfp, "<newNumberVector\n");
@@ -574,6 +578,8 @@ void INDI::BaseClient::sendNewNumber (INumberVectorProperty *nvp)
     fprintf(svrwfp, "</newNumberVector>\n");
 
    fflush(svrwfp);
+
+   setlocale(LC_NUMERIC,"");
 }
 
 void INDI::BaseClient::sendNewNumber (const char *deviceName, const char *propertyName, const char* elementName, double value)
