@@ -20,6 +20,7 @@
 #include <string.h>
 #include <errno.h>
 #include <zlib.h>
+#include <locale.h>
 
 #include "basedevice.h"
 #include "baseclient.h"
@@ -108,7 +109,7 @@ void * INDI::BaseDevice::getRawProperty(const char *name, INDI_TYPE type)
     void *pPtr;
     bool pRegistered = false;
 
-    std::vector<INDI::Property *>::iterator orderi;
+    typename std::vector<INDI::Property *>::iterator orderi = pAll.begin();
 
     INumberVectorProperty *nvp;
     ITextVectorProperty *tvp;
@@ -116,7 +117,7 @@ void * INDI::BaseDevice::getRawProperty(const char *name, INDI_TYPE type)
     ILightVectorProperty *lvp;
     IBLOBVectorProperty *bvp;
 
-    for (orderi = pAll.begin(); orderi != pAll.end(); orderi++)
+    for (; orderi != pAll.end(); ++orderi)
     {
         pType       = (*orderi)->getType();
         pPtr        = (*orderi)->getProperty();
@@ -189,7 +190,7 @@ INDI::Property * INDI::BaseDevice::getProperty(const char *name, INDI_TYPE type)
     ILightVectorProperty *lvp;
     IBLOBVectorProperty *bvp;
 
-    for (orderi = pAll.begin(); orderi != pAll.end(); orderi++)
+    for (orderi = pAll.begin(); orderi != pAll.end(); ++orderi)
     {
         pType       = (*orderi)->getType();
         pPtr        = (*orderi)->getProperty();
@@ -261,7 +262,7 @@ int INDI::BaseDevice::removeProperty(const char *name, char *errmsg)
     ILightVectorProperty *lvp;
     IBLOBVectorProperty *bvp;
 
-    for (orderi = pAll.begin(); orderi != pAll.end(); orderi++)
+    for (orderi = pAll.begin(); orderi != pAll.end(); ++orderi)
     {
         pType       = (*orderi)->getType();
         pPtr        = (*orderi)->getProperty();
@@ -779,6 +780,8 @@ int INDI::BaseDevice::setValue (XMLEle *root, char * errmsg)
         stateSet = true;
     }
 
+    setlocale(LC_NUMERIC,"C");
+
     /* allow changing the timeout */
     ap = findXMLAtt (root, "timeout");
     if (ap)
@@ -819,6 +822,8 @@ int INDI::BaseDevice::setValue (XMLEle *root, char * errmsg)
               np->max = atof(findXMLAttValu(ep, "max"));
        }
 
+       setlocale(LC_NUMERIC,"");
+
        if (mediator)
            mediator->newNumber(nvp);
 
