@@ -33,7 +33,8 @@ const char *DATETIME_TAB = "Date/Time";
 const char *SITE_TAB = 	"Site Management";
 const char *OPTIONS_TAB = "Options";
 const char *FILTER_TAB = "Filter Wheel";
-const char *GUIDER_TAB = "Guide Wheel";
+const char *FOCUS_TAB = "Focuser";
+const char *GUIDE_TAB = "Guide";
 
 void timerfunc(void *t)
 {
@@ -58,6 +59,7 @@ INDI::DefaultDevice::DefaultDevice()
 
     majorVersion = 1;
     minorVersion = 0;
+
 }
 
 INDI::DefaultDevice::~DefaultDevice()
@@ -298,6 +300,20 @@ bool INDI::DefaultDevice::ISNewSwitch (const char *dev, const char *name, ISStat
         return true;
     }
 
+    if (!strcmp(svp->name, "DEBUG_LEVEL") || !strcmp(svp->name, "LOGGING_LEVEL") || !strcmp(svp->name, "LOG_OUTPUT"))
+    {
+        bool rc = Logger::ISNewSwitch(dev, name, states, names, n);
+
+        if (!strcmp(svp->name, "LOG_OUTPUT"))
+        {
+                ISwitch *sw = IUFindSwitch(svp, "FILE_DEBUG");
+                if (sw && sw->s == ISS_ON)
+                    DEBUGF(Logger::DBG_SESSION, "Session log file %s", Logger::getLogFile().c_str());
+        }
+
+        return rc;
+    }
+
     return false;
 
 }
@@ -358,6 +374,12 @@ void INDI::DefaultDevice::setDebug(bool enable)
     }
 
     pDebug = enable;
+
+    // Inform logger
+    if (Logger::updateProperties(enable, this) == false)
+      DEBUG(Logger::DBG_WARNING,"setLogDebug: Logger error");
+
+    debugTriggered(enable);
     DebugSP.s = IPS_OK;
     IDSetSwitch(&DebugSP, NULL);
 
@@ -395,6 +417,7 @@ void INDI::DefaultDevice::setSimulation(bool enable)
    }
 
    pSimulation = enable;
+   simulationTriggered(enable);
    SimulationSP.s = IPS_OK;
    IDSetSwitch(&SimulationSP, NULL);
 
@@ -410,6 +433,16 @@ bool INDI::DefaultDevice::isSimulation()
  return pSimulation;
 }
 
+void INDI::DefaultDevice::debugTriggered(bool enable)
+{
+    INDI_UNUSED(enable);
+}
+
+void INDI::DefaultDevice::simulationTriggered(bool enable)
+{
+    INDI_UNUSED(enable);
+}
+
 void INDI::DefaultDevice::ISGetProperties (const char *dev)
 {
     std::vector<INDI::Property *>::iterator orderi;
@@ -591,6 +624,13 @@ bool INDI::DefaultDevice::initProperties()
     IUFillSwitch(&ConfigProcessS[2], "CONFIG_DEFAULT", "Default", ISS_OFF);
     IUFillSwitchVector(&ConfigProcessSP, ConfigProcessS, NARRAY(ConfigProcessS), getDeviceName(), "CONFIG_PROCESS", "Configuration", "Options", IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
 
+    // Ready the logger
+    std::string logFile;
+    logFile += "/tmp/";
+    logFile += getDriverExec();
+
+    DEBUG_CONF(logFile,  Logger::file_off|Logger::screen_on, Logger::defaultlevel, Logger::defaultlevel);
+
    return true;
 }
 
