@@ -28,7 +28,7 @@
 const char *IMAGE_SETTINGS_TAB = "Image Settings";
 const char *IMAGE_INFO_TAB     = "Image Info";
 const char *GUIDE_HEAD_TAB     = "Guide Head";
-const char *GUIDE_CONTROL_TAB     = "Guider Control";
+const char *GUIDE_CONTROL_TAB  = "Guider Control";
 
 CCDChip::CCDChip()
 {
@@ -69,11 +69,9 @@ CCDChip::~CCDChip()
     delete FitsBP;
 }
 
-int CCDChip::setFrameType(CCD_FRAME t)
+void CCDChip::setFrameType(CCD_FRAME type)
 {
-    //fprintf(stderr,"Set frame type to %d\n",t);
-    FrameType=t;
-    return 0;
+    FrameType=type;
 }
 
 void CCDChip::setResolutoin(int x, int y)
@@ -86,7 +84,14 @@ void CCDChip::setResolutoin(int x, int y)
 
     IDSetNumber(ImagePixelSizeNP, NULL);
 
+    ImageFrameN[FRAME_X].min = 0;
+    ImageFrameN[FRAME_X].max = x-1;
+    ImageFrameN[FRAME_Y].min = 0;
+    ImageFrameN[FRAME_Y].max = y-1;
+
+    ImageFrameN[FRAME_W].min = 1;
     ImageFrameN[FRAME_W].max = x;
+    ImageFrameN[FRAME_H].max = 1;
     ImageFrameN[FRAME_H].max = y;
     IUUpdateMinMax(ImageFrameNP);
 }
@@ -151,6 +156,7 @@ void CCDChip::setFrameBufferSize(int nbuf)
     RawFrameSize = nbuf;
 
     RawFrame = new char[nbuf];
+
 }
 
 void CCDChip::setExposureLeft(double duration)
@@ -166,6 +172,11 @@ void CCDChip::setExposureDuration(double duration)
     gettimeofday(&startExposureTime,NULL);
 }
 
+const char *CCDChip::getFrameTypeName(CCD_FRAME fType)
+{
+    return FrameTypeS[fType].name;
+}
+
 const char * CCDChip::getExposureStartTime()
 {
     static char ts[32];
@@ -195,6 +206,9 @@ INDI::CCD::CCD()
     HasGuideHead=false;
     HasSt4Port=false;
     InExposure=false;
+    InGuideExposure=false;
+    RA=0.0;
+    Dec=90.0;
     ActiveDeviceTP = new ITextVectorProperty;
 }
 
@@ -212,7 +226,7 @@ bool INDI::CCD::initProperties()
     IUFillNumber(&PrimaryCCD.ImageFrameN[0],"X","Left ","%4.0f",0,1392.0,0,0);
     IUFillNumber(&PrimaryCCD.ImageFrameN[1],"Y","Top","%4.0f",0,1040,0,0);
     IUFillNumber(&PrimaryCCD.ImageFrameN[2],"WIDTH","Width","%4.0f",0,1392.0,0,1392.0);
-    IUFillNumber(&PrimaryCCD.ImageFrameN[3],"HEIGHT","Height","%4.0f",0,1040,0,1040);
+    IUFillNumber(&PrimaryCCD.ImageFrameN[3],"HEIGHT","Height","%4.0f",0,1392,0,1392.0);
     IUFillNumberVector(PrimaryCCD.ImageFrameNP,PrimaryCCD.ImageFrameN,4,getDeviceName(),"CCD_FRAME","Frame",IMAGE_SETTINGS_TAB,IP_RW,60,IPS_IDLE);
 
     IUFillSwitch(&PrimaryCCD.FrameTypeS[0],"FRAME_LIGHT","Light",ISS_ON);
@@ -239,12 +253,12 @@ bool INDI::CCD::initProperties()
     IUFillNumber(&PrimaryCCD.ImagePixelSizeN[5],"CCD_BITSPERPIXEL","Bits per pixel","%3.0f",1,40,0,6.45);
     IUFillNumberVector(PrimaryCCD.ImagePixelSizeNP,PrimaryCCD.ImagePixelSizeN,6,getDeviceName(),"CCD_INFO","CCD Information",IMAGE_INFO_TAB,IP_RO,60,IPS_IDLE);
 
-    IUFillSwitch(&PrimaryCCD.CompressS[0],"COMPRESS","Compress",ISS_OFF);
-    IUFillSwitch(&PrimaryCCD.CompressS[1],"RAW","Raw",ISS_ON);
-    IUFillSwitchVector(PrimaryCCD.CompressSP,PrimaryCCD.CompressS,2,getDeviceName(),"COMPRESSION","Image",IMAGE_SETTINGS_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
+    IUFillSwitch(&PrimaryCCD.CompressS[0],"COMPRESS","Compress",ISS_ON);
+    IUFillSwitch(&PrimaryCCD.CompressS[1],"RAW","Raw",ISS_OFF);
+    IUFillSwitchVector(PrimaryCCD.CompressSP,PrimaryCCD.CompressS,2,getDeviceName(),"CCD_COMPRESSION","Image",IMAGE_SETTINGS_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
     IUFillBLOB(&PrimaryCCD.FitsB,"CCD1","Image","");
-    IUFillBLOBVector(PrimaryCCD.FitsBP,&PrimaryCCD.FitsB,1,getDeviceName(),"CCD1","Image Data",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
+    IUFillBLOBVector(PrimaryCCD.FitsBP,&PrimaryCCD.FitsB,1,getDeviceName(),"CCD1","Image Data",IMAGE_INFO_TAB,IP_RO,60,IPS_IDLE);
 
     // GUIDER CCD Init
 
@@ -252,7 +266,11 @@ bool INDI::CCD::initProperties()
     IUFillNumber(&GuideCCD.ImageFrameN[1],"Y","Top","%4.0f",0,1040,0,0);
     IUFillNumber(&GuideCCD.ImageFrameN[2],"WIDTH","Width","%4.0f",0,1392.0,0,1392.0);
     IUFillNumber(&GuideCCD.ImageFrameN[3],"HEIGHT","Height","%4.0f",0,1040,0,1040);
-    IUFillNumberVector(GuideCCD.ImageFrameNP,GuideCCD.ImageFrameN,4,getDeviceName(),"GUIDE_FRAME","Frame",GUIDE_HEAD_TAB,IP_RW,60,IPS_IDLE);
+    IUFillNumberVector(GuideCCD.ImageFrameNP,GuideCCD.ImageFrameN,4,getDeviceName(),"GUIDER_FRAME","Frame",GUIDE_HEAD_TAB,IP_RW,60,IPS_IDLE);
+
+    IUFillNumber(&GuideCCD.ImageBinN[0],"HOR_BIN","X","%2.0f",1,4,1,1);
+    IUFillNumber(&GuideCCD.ImageBinN[1],"VER_BIN","Y","%2.0f",1,4,1,1);
+    IUFillNumberVector(GuideCCD.ImageBinNP,GuideCCD.ImageBinN,2,getDeviceName(),"GUIDE_BINNING","Binning",GUIDE_HEAD_TAB,IP_RW,60,IPS_IDLE);
 
     IUFillNumber(&GuideCCD.ImagePixelSizeN[0],"CCD_MAX_X","Resolution x","%4.0f",1,40,0,6.45);
     IUFillNumber(&GuideCCD.ImagePixelSizeN[1],"CCD_MAX_Y","Resolution y","%4.0f",1,40,0,6.45);
@@ -260,20 +278,27 @@ bool INDI::CCD::initProperties()
     IUFillNumber(&GuideCCD.ImagePixelSizeN[3],"CCD_PIXEL_SIZE_X","Pixel size X","%5.2f",1,40,0,6.45);
     IUFillNumber(&GuideCCD.ImagePixelSizeN[4],"CCD_PIXEL_SIZE_Y","Pixel size Y","%5.2f",1,40,0,6.45);
     IUFillNumber(&GuideCCD.ImagePixelSizeN[5],"CCD_BITSPERPIXEL","Bits per pixel","%3.0f",1,40,0,6.45);
-    IUFillNumberVector(GuideCCD.ImagePixelSizeNP,GuideCCD.ImagePixelSizeN,6,getDeviceName(),"GUIDE_INFO",GUIDE_HEAD_TAB,GUIDE_HEAD_TAB,IP_RO,60,IPS_IDLE);
+    IUFillNumberVector(GuideCCD.ImagePixelSizeNP,GuideCCD.ImagePixelSizeN,6,getDeviceName(),"GUIDER_INFO", "Guide Info",IMAGE_INFO_TAB,IP_RO,60,IPS_IDLE);
+
+    IUFillSwitch(&GuideCCD.FrameTypeS[0],"FRAME_LIGHT","Light",ISS_ON);
+    IUFillSwitch(&GuideCCD.FrameTypeS[1],"FRAME_BIAS","Bias",ISS_OFF);
+    IUFillSwitch(&GuideCCD.FrameTypeS[2],"FRAME_DARK","Dark",ISS_OFF);
+    IUFillSwitch(&GuideCCD.FrameTypeS[3],"FRAME_FLAT","Flat",ISS_OFF);
+    IUFillSwitchVector(GuideCCD.FrameTypeSP,GuideCCD.FrameTypeS,4,getDeviceName(),"GUIDE_FRAME_TYPE","FrameType",GUIDE_HEAD_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
+
 
     IUFillNumber(&GuideCCD.ImageExposureN[0],"GUIDER_EXPOSURE_VALUE","Duration (s)","%5.2f",0,36000,0,1.0);
-    IUFillNumberVector(GuideCCD.ImageExposureNP,GuideCCD.ImageExposureN,1,getDeviceName(),"GUIDER_EXPOSURE","Guide",MAIN_CONTROL_TAB,IP_RW,60,IPS_IDLE);
+    IUFillNumberVector(GuideCCD.ImageExposureNP,GuideCCD.ImageExposureN,1,getDeviceName(),"GUIDER_EXPOSURE","Guide Head",MAIN_CONTROL_TAB,IP_RW,60,IPS_IDLE);
 
     IUFillSwitch(&GuideCCD.AbortExposureS[0],"ABORT","Abort",ISS_OFF);
     IUFillSwitchVector(GuideCCD.AbortExposureSP,GuideCCD.AbortExposureS,1,getDeviceName(),"GUIDER_ABORT_EXPOSURE","Guide Abort",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
-    IUFillSwitch(&GuideCCD.CompressS[0],"GCOMPRESS","Compress",ISS_OFF);
-    IUFillSwitch(&GuideCCD.CompressS[1],"GRAW","Raw",ISS_ON);
-    IUFillSwitchVector(GuideCCD.CompressSP,GuideCCD.CompressS,2,getDeviceName(),"GCOMPRESSION","Image",GUIDE_HEAD_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
+    IUFillSwitch(&GuideCCD.CompressS[0],"GCOMPRESS","Compress",ISS_ON);
+    IUFillSwitch(&GuideCCD.CompressS[1],"GRAW","Raw",ISS_OFF);
+    IUFillSwitchVector(GuideCCD.CompressSP,GuideCCD.CompressS,2,getDeviceName(),"GUIDER_COMPRESSION","Image",GUIDE_HEAD_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
     IUFillBLOB(&GuideCCD.FitsB,"CCD2","Guider Image","");
-    IUFillBLOBVector(GuideCCD.FitsBP,&GuideCCD.FitsB,1,getDeviceName(),"CCD2","Image Data",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
+    IUFillBLOBVector(GuideCCD.FitsBP,&GuideCCD.FitsB,1,getDeviceName(),"CCD2","Image Data",IMAGE_INFO_TAB,IP_RO,60,IPS_IDLE);
 
     // CCD Class Init
 
@@ -283,11 +308,9 @@ bool INDI::CCD::initProperties()
 
     IUFillNumber(&EqN[0],"RA","Ra (hh:mm:ss)","%010.6m",0,24,0,0);
     IUFillNumber(&EqN[1],"DEC","Dec (dd:mm:ss)","%010.6m",-90,90,0,0);
-    IUFillNumberVector(&EqNP,EqN,2,ActiveDeviceT[0].text,"EQUATORIAL_COORD","EQ Coord","Main Control",IP_RW,60,IPS_IDLE);
+    IUFillNumberVector(&EqNP,EqN,2,ActiveDeviceT[0].text,"EQUATORIAL_EOD_COORD","EQ Coord","Main Control",IP_RW,60,IPS_IDLE);
 
-    IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_COORD");
-    IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
-    IDSnoopDevice(ActiveDeviceT[1].text,"FWHM");
+    IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_EOD_COORD");
 
 
     // Guider Interface
@@ -329,6 +352,7 @@ bool INDI::CCD::updateProperties()
         if(HasGuideHead)
         {
             defineNumber(GuideCCD.ImagePixelSizeNP);
+            defineNumber(GuideCCD.ImageBinNP);
         }
         defineSwitch(PrimaryCCD.CompressSP);
         defineBLOB(PrimaryCCD.FitsBP);
@@ -339,10 +363,12 @@ bool INDI::CCD::updateProperties()
         }
         if(HasSt4Port)
         {
-            defineNumber(&GuideNSP);
-            defineNumber(&GuideEWP);
+            defineNumber(&GuideNSNP);
+            defineNumber(&GuideWENP);
         }
         defineSwitch(PrimaryCCD.FrameTypeSP);
+        if (HasGuideHead)
+            defineSwitch(GuideCCD.FrameTypeSP);
         defineText(ActiveDeviceTP);
     }
     else
@@ -361,12 +387,14 @@ bool INDI::CCD::updateProperties()
             deleteProperty(GuideCCD.ImageFrameNP->name);
             deleteProperty(GuideCCD.ImagePixelSizeNP->name);
             deleteProperty(GuideCCD.FitsBP->name);
+            deleteProperty(GuideCCD.ImageBinNP->name);
             deleteProperty(GuideCCD.CompressSP->name);
+            deleteProperty(GuideCCD.FrameTypeSP->name);
         }
         if(HasSt4Port)
         {
-            deleteProperty(GuideNSP.name);
-            deleteProperty(GuideEWP.name);
+            deleteProperty(GuideNSNP.name);
+            deleteProperty(GuideWENP.name);
 
         }
         deleteProperty(PrimaryCCD.FrameTypeSP->name);
@@ -376,8 +404,7 @@ bool INDI::CCD::updateProperties()
 }
 
 bool INDI::CCD::ISSnoopDevice (XMLEle *root)
- {
-     //fprintf(stderr," ################# CCDSim handling snoop ##############\n");
+{
      if(IUSnoopNumber(root,&EqNP)==0)
      {
         float newra,newdec;
@@ -385,7 +412,7 @@ bool INDI::CCD::ISSnoopDevice (XMLEle *root)
         newdec=EqN[1].value;
         if((newra != RA)||(newdec != Dec))
         {
-            //fprintf(stderr,"RA %4.2f  Dec %4.2f Snooped RA %4.2f  Dec %4.2f\n",RA,Dec,newra,newdec);
+            //IDLog("RA %4.2f  Dec %4.2f Snooped RA %4.2f  Dec %4.2f\n",RA,Dec,newra,newdec);
             RA=newra;
             Dec=newdec;
 
@@ -396,13 +423,11 @@ bool INDI::CCD::ISSnoopDevice (XMLEle *root)
         //fprintf(stderr,"Snoop Failed\n");
      }
 
-     return true;
+     return INDI::DefaultDevice::ISSnoopDevice(root);
  }
 
 bool INDI::CCD::ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n)
 {
-    //  Ok, lets see if this is a property wer process
-    //IDLog("IndiTelescope got %d new text items name %s\n",n,name);
     //  first check if it's for our device
     if(strcmp(dev,getDeviceName())==0)
     {
@@ -411,18 +436,19 @@ bool INDI::CCD::ISNewText (const char *dev, const char *name, char *texts[], cha
         if(strcmp(name,ActiveDeviceTP->name)==0)
         {
             int rc;
-            //IDLog("calling update text\n");
             ActiveDeviceTP->s=IPS_OK;
             rc=IUUpdateText(ActiveDeviceTP,texts,names,n);
-            //IDLog("update text returns %d\n",rc);
             //  Update client display
             IDSetText(ActiveDeviceTP,NULL);
             saveConfig();
-            IUFillNumberVector(&EqNP,EqN,2,ActiveDeviceT[0].text,"EQUATORIAL_PEC","EQ PEC",MAIN_CONTROL_TAB,IP_RW,60,IPS_IDLE);
 
-            IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_PEC");
-            IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
-            IDSnoopDevice(ActiveDeviceT[1].text,"FWHM");
+            // Update the property name!
+            strncpy(EqNP.device, ActiveDeviceT[0].text, MAXINDIDEVICE);
+            IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_EOD_COORD");
+
+            // Tell children active devices was updated.
+            activeDevicesUpdated();
+
             //  We processed this one, so, tell the world we did it
             return true;
         }
@@ -521,7 +547,24 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
 
             return true;
 
-      }
+        }
+
+        if(strcmp(name,"GUIDE_BINNING")==0)
+        {
+            //  We are being asked to set camera binning
+            GuideCCD.ImageBinNP->s=IPS_OK;
+            IUUpdateNumber(GuideCCD.ImageBinNP,values,names,n);
+
+
+            if (updateGuideBin(GuideCCD.ImageBinN[0].value, GuideCCD.ImageBinN[1].value) == false)
+            {
+                GuideCCD.ImageBinNP->s = IPS_ALERT;
+                IDSetNumber (GuideCCD.ImageBinNP, NULL);
+            }
+
+            return true;
+
+        }
 
         if(strcmp(name,"CCD_FRAME")==0)
         {
@@ -531,11 +574,9 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
 
             if (updateCCDFrame(PrimaryCCD.ImageFrameN[0].value, PrimaryCCD.ImageFrameN[1].value, PrimaryCCD.ImageFrameN[2].value,
                                PrimaryCCD.ImageFrameN[3].value) == false)
-            {
                 PrimaryCCD.ImageFrameNP->s = IPS_ALERT;
-                IDSetNumber(PrimaryCCD.ImageFrameNP, NULL);
 
-            }
+            IDSetNumber(PrimaryCCD.ImageFrameNP, NULL);
             return true;
         }
 
@@ -544,23 +585,20 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
             //  We are being asked to set camera binning
             GuideCCD.ImageFrameNP->s=IPS_OK;
             IUUpdateNumber(GuideCCD.ImageFrameNP,values,names,n);
-            //  Update client display
-            //IDSetNumber(GuiderFrameNP,NULL);
 
-            if (isDebug())
-                IDLog("GuiderFrame set to %4.0f,%4.0f %4.0f x %4.0f\n",
+            DEBUGF(Logger::DBG_DEBUG, "GuiderFrame set to %4.0f,%4.0f %4.0f x %4.0f",
                   GuideCCD.ImageFrameN[0].value,GuideCCD.ImageFrameN[1].value,GuideCCD.ImageFrameN[2].value,GuideCCD.ImageFrameN[3].value);
-            //GSubX=GuiderFrameN[0].value;
-            //GSubY=GuiderFrameN[1].value;
-            //GSubW=GuiderFrameN[2].value;
-            //GSubH=GuiderFrameN[3].value;
-            GuideCCD.setFrame(GuideCCD.ImageFrameN[0].value, GuideCCD.ImageFrameN[1].value,
-                              GuideCCD.ImageFrameN[2].value,GuideCCD.ImageFrameN[3].value);
+
+            if (updateGuideFrame(GuideCCD.ImageFrameN[0].value, GuideCCD.ImageFrameN[1].value, GuideCCD.ImageFrameN[2].value,
+                               GuideCCD.ImageFrameN[3].value) == false)
+                GuideCCD.ImageFrameNP->s = IPS_ALERT;
+
+            IDSetNumber(GuideCCD.ImageFrameNP, NULL);
 
             return true;
         }
 
-        if (!strcmp(name,GuideNSP.name) || !strcmp(name,GuideEWP.name))
+        if (!strcmp(name,GuideNSNP.name) || !strcmp(name,GuideWENP.name))
         {
             processGuiderProperties(name, values, names, n);
             return true;
@@ -674,6 +712,24 @@ bool INDI::CCD::ISNewSwitch (const char *dev, const char *name, ISState *states,
 
             return true;
         }
+
+        if(strcmp(name,GuideCCD.FrameTypeSP->name)==0)
+        {
+            //  Compression Update
+            IUUpdateSwitch(GuideCCD.FrameTypeSP,states,names,n);
+            GuideCCD.FrameTypeSP->s=IPS_OK;
+            if(GuideCCD.FrameTypeS[0].s==ISS_ON) GuideCCD.setFrameType(CCDChip::LIGHT_FRAME);
+            else if(GuideCCD.FrameTypeS[1].s==ISS_ON) GuideCCD.setFrameType(CCDChip::BIAS_FRAME);
+            else if(GuideCCD.FrameTypeS[2].s==ISS_ON) GuideCCD.setFrameType(CCDChip::DARK_FRAME);
+            else if(GuideCCD.FrameTypeS[3].s==ISS_ON) GuideCCD.setFrameType(CCDChip::FLAT_FRAME);
+
+            if (updateGuideFrameType(GuideCCD.getFrameType()) == false)
+                GuideCCD.FrameTypeSP->s = IPS_ALERT;
+
+            IDSetSwitch(GuideCCD.FrameTypeSP,NULL);
+
+            return true;
+        }
     }
 
 
@@ -707,6 +763,12 @@ bool INDI::CCD::updateCCDFrame(int x, int y, int w, int h)
     return true;
 }
 
+bool INDI::CCD::updateGuideFrame(int x, int y, int w, int h)
+{
+    GuideCCD.setFrame(x,y, w,h);
+    return true;
+}
+
 bool INDI::CCD::updateCCDBin(int hor, int ver)
 {
     // Just set value, unless HW layer overrides this and performs its own processing
@@ -714,6 +776,14 @@ bool INDI::CCD::updateCCDBin(int hor, int ver)
     return true;
 }
 
+
+bool INDI::CCD::updateGuideBin(int hor, int ver)
+{
+    // Just set value, unless HW layer overrides this and performs its own processing
+    GuideCCD.setBin(hor, ver);
+    return true;
+}
+
 bool INDI::CCD::updateCCDFrameType(CCDChip::CCD_FRAME fType)
 {
     INDI_UNUSED(fType);
@@ -721,6 +791,13 @@ bool INDI::CCD::updateCCDFrameType(CCDChip::CCD_FRAME fType)
     return true;
 }
 
+bool INDI::CCD::updateGuideFrameType(CCDChip::CCD_FRAME fType)
+{
+    INDI_UNUSED(fType);
+    // Child classes can override this
+    return true;
+}
+
 void INDI::CCD::addFITSKeywords(fitsfile *fptr, CCDChip *targetChip)
 {
     int status=0;
@@ -737,7 +814,6 @@ void INDI::CCD::addFITSKeywords(fitsfile *fptr, CCDChip *targetChip)
     xbin = targetChip->getBinX();
     ybin = targetChip->getBinY();
 
-
     switch (targetChip->getFrameType())
     {
       case CCDChip::LIGHT_FRAME:
@@ -777,7 +853,6 @@ void INDI::CCD::addFITSKeywords(fitsfile *fptr, CCDChip *targetChip)
     fits_update_key_s(fptr, TSTRING, "INSTRUME", dev_name, "CCD Name", &status);
     fits_update_key_s(fptr, TSTRING, "DATE-OBS", exp_start, "UTC start date of observation", &status);
 
-    //fits_write_date(fptr, &status);
 }
 
 void INDI::CCD::fits_update_key_s(fitsfile* fptr, int type, std::string name, void* p, std::string explanation, int* status)
@@ -796,6 +871,7 @@ bool INDI::CCD::ExposureComplete(CCDChip *targetChip)
     long naxes[2];
     long naxis=2;
     int nelements=0;
+    std::string bit_depth;
 
     fitsfile *fptr=NULL;
 
@@ -807,20 +883,23 @@ bool INDI::CCD::ExposureComplete(CCDChip *targetChip)
         case 8:
             byte_type = TBYTE;
             img_type  = BYTE_IMG;
+            bit_depth = "8 bits per pixel";
             break;
 
         case 16:
             byte_type = TUSHORT;
             img_type = USHORT_IMG;
+            bit_depth = "16 bits per pixel";
             break;
 
         case 32:
             byte_type = TULONG;
             img_type = ULONG_IMG;
+            bit_depth = "32 bits per pixel";
             break;
 
          default:
-            IDLog("Unsupported bits per pixel value %d\n", targetChip->getBPP() );
+            DEBUGF(Logger::DBG_WARNING, "Unsupported bits per pixel value %d\n", targetChip->getBPP() );
             return false;
             break;
     }
@@ -828,6 +907,9 @@ bool INDI::CCD::ExposureComplete(CCDChip *targetChip)
 
     nelements = naxes[0] * naxes[1];
 
+    DEBUGF(Logger::DBG_DEBUG, "Exposure complete. Image Depth: %s. Width: %d Height: %d nelements: %d", bit_depth.c_str(), naxes[0],
+            naxes[1], nelements);
+
     //  Now we have to send fits format data to the client
     memsize=5760;
     memptr=malloc(memsize);
@@ -870,7 +952,6 @@ bool INDI::CCD::ExposureComplete(CCDChip *targetChip)
     targetChip->ImageExposureNP->s=IPS_OK;
     IDSetNumber(targetChip->ImageExposureNP,NULL);
 
-
     targetChip->FitsB.blob=memptr;
     targetChip->FitsB.bloblen=memsize;
     targetChip->FitsB.size=memsize;
@@ -893,7 +974,7 @@ void INDI::CCD::SetCCDParams(int x,int y,int bpp,float xf,float yf)
 
 }
 
-void INDI::CCD::SetGuidHeadParams(int x,int y,int bpp,float xf,float yf)
+void INDI::CCD::SetGuideHeadParams(int x,int y,int bpp,float xf,float yf)
 {
     HasGuideHead=true;
 
