@@ -21,12 +21,12 @@
 #include <string.h>
 
 #include "indifilterinterface.h"
+#include "indilogger.h"
 
 INDI::FilterInterface::FilterInterface()
 {
     FilterNameTP  = new ITextVectorProperty;
     FilterNameT  = NULL;
-    MinFilter = MaxFilter = 0;
 }
 
 void INDI::FilterInterface::initFilterProperties(const char *deviceName, const char* groupName)
@@ -52,12 +52,8 @@ void INDI::FilterInterface::SelectFilterDone(int f)
     IDSetNumber(&FilterSlotNP,NULL);
 }
 
-void INDI::FilterInterface::processFilterProperties(const char *name, double values[], char *names[], int n)
+void INDI::FilterInterface::processFilterSlot(const char *deviceName, double values[], char *names[])
 {
-
-    if (!strcmp(FilterSlotNP.name, name))
-    {
-
         TargetFilter = values[0];
 
         INumber *np = IUFindNumber(&FilterSlotNP, names[0]);
@@ -65,25 +61,44 @@ void INDI::FilterInterface::processFilterProperties(const char *name, double val
         if (!np)
         {
             FilterSlotNP.s = IPS_ALERT;
-            IDSetNumber(&FilterSlotNP, "Unknown error. %s is not a member of %s property.", names[0], name);
+            DEBUGFDEVICE(deviceName, Logger::DBG_ERROR, "Unknown error. %s is not a member of %s property.", names[0], FilterSlotNP.name);
+            IDSetNumber(&FilterSlotNP, NULL);
             return;
         }
 
-        if (TargetFilter < MinFilter || TargetFilter > MaxFilter)
+        if (TargetFilter < FilterSlotN[0].min || TargetFilter > FilterSlotN[0].max)
         {
             FilterSlotNP.s = IPS_ALERT;
-            IDSetNumber(&FilterSlotNP, "Error: valid range of filter is from %d to %d", MinFilter, MaxFilter);
+            DEBUGFDEVICE(deviceName, Logger::DBG_ERROR, "Error: valid range of filter is from %g to %g", FilterSlotN[0].min, FilterSlotN[0].max);
+            IDSetNumber(&FilterSlotNP, NULL);
             return;
         }
 
         FilterSlotNP.s = IPS_BUSY;
-        IDSetNumber(&FilterSlotNP, "Setting current filter to slot %d", TargetFilter);
+        DEBUGFDEVICE(deviceName, Logger::DBG_SESSION, "Setting current filter to slot %d", TargetFilter);
+        IDSetNumber(&FilterSlotNP, NULL);
 
         SelectFilter(TargetFilter);
 
         return;
 
+}
+
+void INDI::FilterInterface::processFilterName(const char *deviceName, char *texts[], char *names[], int n)
+{
+    int rc;
+    FilterNameTP->s=IPS_OK;
+    rc=IUUpdateText(FilterNameTP,texts,names,n);
+
+    if (SetFilterNames() == true)
+        IDSetText(FilterNameTP,NULL);
+    else
+    {
+        FilterNameTP->s = IPS_ALERT;
+        DEBUGDEVICE(deviceName, Logger::DBG_ERROR, "Error updating names of filters.");
+        IDSetText(FilterNameTP, NULL);
     }
+
 }
 
 
