@@ -23,7 +23,6 @@
 INDI::FilterWheel::FilterWheel()
 {
     //ctor
-    MaxFilter=-1;
 }
 
 INDI::FilterWheel::~FilterWheel()
@@ -92,30 +91,8 @@ bool INDI::FilterWheel::ISNewNumber (const char *dev, const char *name, double v
 
         if(strcmp(name,"FILTER_SLOT")==0)
         {
-            int f;
-
-            f=-1;
-            for(int x=0; x<n; x++)
-            {
-                if(strcmp(names[x],"FILTER_SLOT_VALUE")==0)
-                {
-                    //  This is the new filter number we are being asked
-                    //  to set as active
-                    f=values[x];
-                }
-            }
-
-            if(f != -1)
-            {
-                //IDLog("Filter wheel got a filter slot change\n");
-                //  tell the client we are busy changing the filter
-                FilterSlotNP.s=IPS_BUSY;
-                IDSetNumber(&FilterSlotNP,NULL);
-                //  Tell the hardware to change
-                SelectFilter(f);
-                //  tell the caller we processed this
-                return true;
-            }
+            processFilterSlot(dev, values, names);
+            return true;
         }
     }
     //  if we didn't process it, continue up the chain, let somebody else
@@ -134,19 +111,7 @@ bool INDI::FilterWheel::ISNewText (const char *dev, const char *name, char *text
         //  Now lets see if it's something we process here
         if(strcmp(name,FilterNameTP->name)==0)
         {
-            int rc;
-            //IDLog("calling update text\n");
-            FilterNameTP->s=IPS_OK;
-            rc=IUUpdateText(FilterNameTP,texts,names,n);
-
-            if (SetFilterNames() == true)
-                IDSetText(FilterNameTP,NULL);
-            else
-            {
-                FilterNameTP->s = IPS_ALERT;
-                IDSetText(FilterNameTP, "Error updating names of filters.");
-            }
-            //  We processed this one, so, tell the world we did it
+            processFilterName(dev, texts, names, n);
             return true;
         }
 
