@@ -36,63 +36,65 @@ INDI::GuiderInterface::~GuiderInterface()
 void INDI::GuiderInterface::initGuiderProperties(const char *deviceName, const char* groupName)
 {
 
-    IUFillNumber(&GuideNS[0],"TIMED_GUIDE_N","North (msec)","%g",0,60000,10,0);
-    IUFillNumber(&GuideNS[1],"TIMED_GUIDE_S","South (msec)","%g",0,60000,10,0);
-    IUFillNumberVector(&GuideNSP,GuideNS,2,deviceName,"TELESCOPE_TIMED_GUIDE_NS","Guide North/South",groupName,IP_RW,60,IPS_IDLE);
+    IUFillNumber(&GuideNSN[0],"TIMED_GUIDE_N","North (msec)","%g",0,60000,10,0);
+    IUFillNumber(&GuideNSN[1],"TIMED_GUIDE_S","South (msec)","%g",0,60000,10,0);
+    IUFillNumberVector(&GuideNSNP,GuideNSN,2,deviceName,"TELESCOPE_TIMED_GUIDE_NS","Guide North/South",groupName,IP_RW,60,IPS_IDLE);
 
-    IUFillNumber(&GuideEW[0],"TIMED_GUIDE_E","East (msec)","%g",0,60000,10,0);
-    IUFillNumber(&GuideEW[1],"TIMED_GUIDE_W","West (msec)","%g",0,60000,10,0);
-    IUFillNumberVector(&GuideEWP,GuideEW,2,deviceName,"TELESCOPE_TIMED_GUIDE_WE","Guide East/West",groupName,IP_RW,60,IPS_IDLE);
+    IUFillNumber(&GuideWEN[0],"TIMED_GUIDE_E","East (msec)","%g",0,60000,10,0);
+    IUFillNumber(&GuideWEN[1],"TIMED_GUIDE_W","West (msec)","%g",0,60000,10,0);
+    IUFillNumberVector(&GuideWENP,GuideWEN,2,deviceName,"TELESCOPE_TIMED_GUIDE_WE","Guide East/West",groupName,IP_RW,60,IPS_IDLE);
 }
 
 void INDI::GuiderInterface::processGuiderProperties(const char *name, double values[], char *names[], int n)
 {
-    if(strcmp(name,GuideNSP.name)==0)
+    if(strcmp(name,GuideNSNP.name)==0)
     {
         //  We are being asked to send a guide pulse north/south on the st4 port
-        GuideNSP.s=IPS_BUSY;
-        IUUpdateNumber(&GuideNSP,values,names,n);
+        GuideNSNP.s=IPS_BUSY;
+        IUUpdateNumber(&GuideNSNP,values,names,n);
         //  Update client display
-        IDSetNumber(&GuideNSP,NULL);
+        IDSetNumber(&GuideNSNP,NULL);
 
 
-        if(GuideNS[0].value != 0)
+        if(GuideNSN[0].value != 0)
         {
-            GuideNorth(GuideNS[0].value);
+            GuideNorth(GuideNSN[0].value);
         }
-        if(GuideNS[1].value != 0) {
-            GuideSouth(GuideNS[1].value);
+        if(GuideNSN[1].value != 0) {
+            GuideSouth(GuideNSN[1].value);
         }
-        GuideNS[0].value=0;
-        GuideNS[1].value=0;
-        GuideNSP.s=IPS_OK;
-        IDSetNumber(&GuideNSP,NULL);
+        GuideNSN[0].value=0;
+        GuideNSN[1].value=0;
+        GuideNSNP.s=IPS_OK;
+        IDSetNumber(&GuideNSNP,NULL);
 
         return;
     }
 
-    if(strcmp(name,GuideEWP.name)==0)
+    if(strcmp(name,GuideWENP.name)==0)
     {
         //  We are being asked to send a guide pulse north/south on the st4 port
-        GuideEWP.s=IPS_BUSY;
-        IUUpdateNumber(&GuideEWP,values,names,n);
+        GuideWENP.s=IPS_BUSY;
+        IUUpdateNumber(&GuideWENP,values,names,n);
         //  Update client display
-        IDSetNumber(&GuideEWP,NULL);
+        IDSetNumber(&GuideWENP,NULL);
 
 
-        if(GuideEW[0].value != 0)
+        if(GuideWEN[0].value != 0)
         {
-            GuideEast(GuideEW[0].value);
+            GuideEast(GuideWEN[0].value);
         } else
         {
-            GuideWest(GuideEW[1].value);
+            GuideWest(GuideWEN[1].value);
         }
 
-        GuideEW[0].value=0;
-        GuideEW[1].value=0;
-        GuideEWP.s=IPS_OK;
-        IDSetNumber(&GuideEWP,NULL);
+        GuideWEN[0].value=0;
+        GuideWEN[1].value=0;
+        GuideWENP.s=IPS_OK;
+        IDSetNumber(&GuideWENP,NULL);
 
         return;
     }
 }
+
+
