@@ -37,7 +37,7 @@
    Developers need to subclass INDI::USBDevice to implement any driver within INDI that requires direct read/write/control over USB.
 
 \author Gerry Rozema
-\see Starlight Xpress INDI CCD driver for an example implementation of INDI::USBDevice
+\note This class implements legacy libusb API v0.1
 */
 class INDI::USBDevice
 {
@@ -58,16 +58,15 @@ protected:
 public:
 	int WriteInterrupt(char *,int,int);
 	int ReadInterrupt(char *,int,int);
+    int ControlMessage(unsigned char request_type, unsigned char request, unsigned int value, unsigned int index, char *data, unsigned char len);
 
-	int ControlMessage();
-
-        int WriteBulk(char *buf,int nbytes,int timeout);
-        int ReadBulk(char *buf,int nbytes,int timeout);
+    int WriteBulk(char *buf,int nbytes,int timeout);
+    int ReadBulk(char *buf,int nbytes,int timeout);
 	int FindEndpoints();
 	int Open();
-        USBDevice(void);
-        USBDevice(struct usb_device *);
-        virtual ~USBDevice(void);
+    USBDevice(void);
+    USBDevice(struct usb_device *);
+    virtual ~USBDevice(void);
 };
 
 #endif // USBDEVICE_H
